---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1990-08-07;241
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19900818&codiceRedaz=090G0294&dataVigenza=20251104
dataGU: 19900818
codiceRedaz: 090G0294
dataVigenza: 20251104
---

# Nuove norme in materia di procedimento amministrativo e di diritto di accesso ai documenti amministrativi.

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## PRINCIPI

### Art. 1. - (Principi generali dell'attivita' amministrativa)

1. L'attivita' amministrativa persegue i fini determinati dalla legge ed e' retta da criteri di economicita', di efficacia, di imparzialita', di pubblicita' e di trasparenza secondo le modalita' previste dalla presente legge e dalle altre disposizioni che disciplinano singoli procedimenti , nonche' dai principi dell'ordinamento comunitario.

1-bis. La pubblica amministrazione, nell'adozione di atti di natura non autoritativa, agisce secondo le norme di diritto privato salvo che la legge disponga diversamente.

1-ter. I soggetti privati preposti all'esercizio di attivita' amministrative assicurano il rispetto dei criteri e dei principi di cui al comma 1, con un livello di garanzia non inferiore a quello cui sono tenute le pubbliche amministrazioni in forza delle disposizioni di cui alla presente legge.

2. La pubblica amministrazione non puo' aggravare il procedimento se non per straordinarie e motivate esigenze imposte dallo svolgimento dell'istruttoria.

((2-bis. I rapporti tra il cittadino e la pubblica amministrazione sono improntati ai principi della collaborazione e della buona fede))

### Art. 2. - (Conclusione del procedimento)

1. Ove il procedimento consegua obbligatoriamente ad un'istanza, ovvero debba essere iniziato d'ufficio, le pubbliche amministrazioni hanno il dovere di concluderlo mediante l'adozione di un provvedimento espresso. Se ravvisano la manifesta irricevibilita', inammissibilita', improcedibilita' o infondatezza della domanda, le pubbliche amministrazioni concludono il procedimento con un provvedimento espresso redatto in forma semplificata, la cui motivazione puo' consistere in un sintetico riferimento al punto di fatto o di diritto ritenuto risolutivo.

2. Nei casi in cui disposizioni di legge ovvero i provvedimenti di cui ai commi 3, 4 e 5 non prevedono un termine diverso, i procedimenti amministrativi di competenza delle amministrazioni statali e degli enti pubblici nazionali devono concludersi entro il termine di trenta giorni. (14)

3. Con uno o piu' decreti del Presidente del Consiglio dei ministri, adottati ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, su proposta dei Ministri competenti e di concerto con i Ministri per la pubblica amministrazione e l'innovazione e per la semplificazione normativa, sono individuati i termini non superiori a novanta giorni entro i quali devono concludersi i procedimenti di competenza delle amministrazioni statali. Gli enti pubblici nazionali stabiliscono, secondo i propri ordinamenti, i termini non superiori a novanta giorni entro i quali devono concludersi i procedimenti di propria competenza. (14)

4. Nei casi in cui, tenendo conto della sostenibilita' dei tempi sotto il profilo dell'organizzazione amministrativa, della natura degli interessi pubblici tutelati e della particolare complessita' del procedimento, sono indispensabili termini superiori a novanta giorni per la conclusione dei procedimenti di competenza delle amministrazioni statali e degli enti pubblici nazionali, i decreti di cui al comma 3 sono adottati su proposta anche dei Ministri per la pubblica amministrazione e l'innovazione e per la semplificazione normativa e previa deliberazione del Consiglio dei ministri. I termini ivi previsti non possono comunque superare i centottanta giorni, con la sola esclusione dei procedimenti di acquisto della cittadinanza italiana e di quelli riguardanti l'immigrazione. (14)

4-bis. Le pubbliche amministrazioni misurano e pubblicano nel proprio sito internet istituzionale, nella sezione "Amministrazione trasparente", i tempi effettivi di conclusione dei procedimenti amministrativi di maggiore impatto per i cittadini e per le imprese, comparandoli con i termini previsti dalla normativa vigente. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro per la pubblica amministrazione, previa intesa in Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono definiti modalita' e criteri di misurazione dei tempi effettivi di conclusione dei procedimenti, nonche' le ulteriori modalita' di pubblicazione di cui al primo periodo.

5. Fatto salvo quanto previsto da specifiche disposizioni normative, le autorita' di garanzia e di vigilanza disciplinano, in conformita' ai propri ordinamenti, i termini di conclusione dei procedimenti di rispettiva competenza. (14)

6. I termini per la conclusione del procedimento decorrono dall'inizio del procedimento d'ufficio o dal ricevimento della domanda, se il procedimento e' ad iniziativa di parte.

7. Fatto salvo quanto previsto dall'articolo 17, i termini di cui ai commi 2, 3, 4 e 5 del presente articolo possono essere sospesi, per una sola volta e per un periodo non superiore a trenta giorni, per l'acquisizione di informazioni o di certificazioni relative a fatti, stati o qualita' non attestati in documenti gia' in possesso dell'amministrazione stessa o non direttamente acquisibili presso altre pubbliche amministrazioni. Si applicano le disposizioni dell'articolo 14, comma 2.

8. La tutela in materia di silenzio dell'amministrazione e' disciplinata dal codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n.104. Le sentenze passate in giudicato che accolgono il ricorso proposto avverso il silenzio inadempimento dell'amministrazione sono trasmesse, in via telematica, alla Corte dei conti.

8-bis. Le determinazioni relative ai provvedimenti, alle autorizzazioni, ai pareri, ai nulla osta e agli atti di assenso comunque denominati, adottate dopo la scadenza dei termini di cui agli articoli 14-bis, comma 2, lettera c), 17-bis, commi 1 e 3, 20, comma 1, ovvero successivamente all'ultima riunione di cui all'articolo 14-ter, comma 7, nonche' i provvedimenti di divieto di prosecuzione dell'attivita' e di rimozione degli eventuali effetti, di cui all'articolo 19, commi 3 e 6-bis, primo periodo, adottati dopo la scadenza dei termini ivi previsti, sono inefficaci, fermo restando quanto previsto dall'articolo 21-nonies, ove ne ricorrano i presupposti e le condizioni.

9. La mancata o tardiva emanazione del provvedimento costituisce elemento di valutazione della performance individuale, nonche' di responsabilita' disciplinare e amministrativo-contabile del dirigente e del funzionario inadempiente.

9-bis. ((L'organo di governo individua un soggetto nell'ambito delle figure apicali dell'amministrazione o una unita' organizzativa cui attribuire il potere sostitutivo in caso di inerzia.)) Nell'ipotesi di omessa individuazione il potere sostitutivo si considera attribuito al dirigente generale o, in mancanza, al dirigente preposto all'ufficio o in mancanza al funzionario di piu' elevato livello presente nell'amministrazione. Per ciascun procedimento, sul sito internet istituzionale dell'amministrazione e' pubblicata, in formato tabellare e con collegamento ben visibile nella homepage, l'indicazione del soggetto ((o dell'unita' organizzativa)) a cui e' attribuito il potere sostitutivo e a cui l'interessato puo' rivolgersi ai sensi e per gli effetti del comma 9-ter. Tale soggetto, in caso di ritardo, comunica senza indugio il nominativo del responsabile, ai fini della valutazione dell'avvio del procedimento disciplinare, secondo le disposizioni del proprio ordinamento e dei contratti collettivi nazionali di lavoro, e, in caso di mancata ottemperanza alle disposizioni del presente comma, assume la sua medesima responsabilita' oltre a quella propria.

((

9-ter. Decorso inutilmente il termine per la conclusione del procedimento o quello superiore di cui al comma 7, il responsabile o l'unita' organizzativa di cui al comma 9-bis, d'ufficio o su richiesta dell'interessato, esercita il potere sostitutivo e, entro un termine pari alla meta' di quello originariamente previsto, conclude il procedimento attraverso le strutture competenti o con la nomina di un commissario.

))

9-quater. Il responsabile individuato ai sensi del comma 9-bis, entro il 30 gennaio di ogni anno, comunica all'organo di governo, i procedimenti, suddivisi per tipologia e strutture amministrative competenti, nei quali non e' stato rispettato il termine di conclusione previsto dalla legge o dai regolamenti. Le Amministrazioni provvedono all'attuazione del presente comma, con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri a carico della finanza pubblica.

9-quinquies. Nei provvedimenti rilasciati in ritardo su istanza di parte sono espressamente indicati il termine previsto dalla legge o dai regolamenti e quello effettivamente impiegato. ------------ AGGIORAMENTO (14) La L. 18 giugno 2009, n. 69 ha disposto (con l'art. 7, comma 3)che: - "In sede di prima attuazione della presente legge, gli atti o i provvedimenti di cui ai commi 3, 4 e 5 dell'articolo 2 della legge 7 agosto 1990, n. 241, [. . .] sono adottati entro un anno dalla data di entrata in vigore della presente legge"; - la disposizione di cui al comma 2 del presente articolo si applica dallo scadere del termine di un anno dalla data di entrata in vigore della suddetta legge 69/2009. -le regioni e gli enti locali si adeguano ai termini di cui ai commi 3 e 4 del presente articolo 2 entro un anno dalla data di entrata in vigore della L. 69/2009.

### Art. 2-bis. - Conseguenze per il ritardo dell'amministrazione nella conclusione del procedimento).

1. Le pubbliche amministrazioni e i soggetti di cui all'articolo 1, comma 1-ter, sono tenuti al risarcimento del danno ingiusto cagionato in conseguenza dell'inosservanza dolosa o colposa del termine di conclusione del procedimento.

((1-bis. Fatto salvo quanto previsto dal comma 1 e ad esclusione delle ipotesi di silenzio qualificato e dei concorsi pubblici, in caso di inosservanza del termine di conclusione del procedimento ad istanza di parte, per il quale sussiste l'obbligo di pronunziarsi, l'istante ha diritto di ottenere un indennizzo per il mero ritardo alle condizioni e con le modalita' stabilite dalla legge o, sulla base della legge, da un regolamento emanato ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400. In tal caso le somme corrisposte o da corrispondere a titolo di indennizzo sono detratte dal risarcimento))

((29))

2. COMMA ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104.

--------------- AGGIORNAMENTO (29) Il D.L. 21 giugno 2013, n. 69, convertito con modificazioni dalla L. 9 agosto 2013, n. 98 ha disposto (con l'art. 28, comma 10) che "Le disposizioni del presente articolo si applicano, in via sperimentale e dalla data di entrata in vigore della legge di conversione del presente decreto, ai procedimenti amministrativi relativi all'avvio e all'esercizio dell'attivita' di impresa iniziati successivamente alla medesima data di entrata in vigore. ".

### Art. 3. - (( (Motivazione del provvedimento) ))

1. Ogni provvedimento amministrativo, compresi quelli concernenti l'organizzazione amministrativa, lo svolgimento dei pubblici concorsi ed il personale, deve essere motivato, salvo che nelle ipotesi previste dal comma 2. La motivazione deve indicare i presupposti di fatto e le ragioni giuridiche che hanno determinato la decisione dell'amministrazione, in relazione alle risultanze dell'istruttoria.

2. La motivazione non e' richiesta per gli atti normativi e per quelli a contenuto generale.

3. Se le ragioni della decisione risultano da altro atto dell'amministrazione richiamato dalla decisione stessa, insieme alla comunicazione di quest'ultima deve essere indicato e reso disponibile, a norma della presente legge, anche l'atto cui essa si richiama.

4. In ogni atto notificato al destinatario devono essere indicati il termine e l'autorita' cui e' possibile ricorrere.

### Art. 3-bis. - (Uso della telematica).

1. Per conseguire maggiore efficienza nella loro attivita', le amministrazioni pubbliche ((agiscono mediante strumenti informatici e telematici)), nei rapporti interni, tra le diverse amministrazioni e tra queste e i privati.

## RESPONSABILE DEL PROCEDIMENTO

### Art. 4. - (( (Unita' organizzativa responsabile del procedimento) ))

1. Ove non sia gia' direttamente stabilito per legge o per regolamento, le pubbliche amministrazioni sono tenute a determinare per ciascun tipo di procedimento relativo ad atti di loro competenza l'unita' organizzativa responsabile della istruttoria e di ogni altro adempimento procedimentale, nonche' dell'adozione del provvedimento finale.

2. Le disposizioni adottate ai sensi del comma 1 sono rese pubbliche secondo quanto previsto dai singoli ordinamenti.

### Art. 5. - (Responsabile del procedimento)

1. Il dirigente di ciascuna unita' organizzativa provvede ad assegnare a se' o altro dipendente addetto all'unita' la responsabilita' dell'istruttoria e di ogni altro adempimento inerente il singolo procedimento nonche', eventualmente, dell'adozione del provvedimento finale.

2. Fino a quando non sia effettuata l'assegnazione di cui al comma 1, e' considerato responsabile del singolo procedimento il funzionario preposto alla unita' organizzativa determinata a norma del comma 1 dell'articolo 4.

3. L'unita' organizzativa competente ((, il domicilio digitale)) e il nominativo del responsabile del procedimento sono comunicati ai soggetti di cui all'articolo 7 e, a richiesta, a chiunque vi abbia interesse.

### Art. 6. - (( (Compiti del responsabile del procedimento) ))

1. Il responsabile del procedimento:

- a) valuta, ai fini istruttori, le condizioni di ammissibilita' i requisiti di legittimazione ed i presupposti che siano rilevanti per l'emanazione del provvedimento;
- b) accerta di ufficio i fatti, disponendo il compimento degli atti all'uopo necessari, e adotta ogni misura per l'adeguato e sollecito svolgimento dell'istruttoria. In particolare, puo' chiedere il rilascio di dichiarazioni e la rettifica di dichiarazioni o istanze erronee o incomplete e puo' esperire accertamenti tecnici ed ispezioni ed ordinare esibizioni documentali;
- c) propone l'indizione o, avendone la competenza, indice le conferenze di servizi di cui all'articolo 14;
- d) cura le comunicazioni, le pubblicazioni e le notificazioni previste dalle leggi e dai regolamenti;
- e) adotta, ove ne abbia la competenza, il provvedimento finale, ovvero trasmette gli atti all'organo competente per l'adozione. ((L'organo competente per l'adozione del provvedimento finale, ove diverso dal responsabile del procedimento, non puo' discostarsi dalle risultanze dell'istruttoria condotta dal responsabile del procedimento se non indicandone la motivazione nel provvedimento finale)).

### Art. 6-bis. - (( (Conflitto di interessi). ))

## PARTECIPAZIONE AL PROCEDIMENTO AMMINISTRATIVO

### Art. 7. - (( (Comunicazione di avvio del procedimento) ))

1. Ove non sussistano ragioni di impedimento derivanti da particolari esigenze di celerita' del procedimento, l'avvio del procedimento stesso e' comunicato, con le modalita' previste dall'articolo 8, ai soggetti nei confronti dei quali il provvedimento finale e' destinato a produrre effetti diretti ed a quelli che per legge debbono intervenirvi. Ove parimenti non sussistano le ragioni di impedimento predette, qualora da un provvedimento possa derivare un pregiudizio a soggetti individuati o facilmente individuabili, diversi dai suoi diretti destinatari, l'amministrazione e' tenuta a fornire loro, con le stesse modalita', notizia dell'inizio del procedimento.

2. Nelle ipotesi di cui al comma 1 resta salva la facolta' dell'amministrazione di adottare, anche prima della effettuazione delle comunicazioni di cui al medesimo comma 1, provvedimenti cautelari.

### Art. 8. - (Modalita' e contenuti della comunicazione di avvio del procedimento)

1. L'amministrazione provvede a dare notizia dell'avvio del procedimento mediante comunicazione personale.

2. Nella comunicazione debbono essere indicati:

- a) l'amministrazione competente;
- b) l'oggetto del procedimento promosso;
- c) l'ufficio ((, il domicilio digitale dell'amministrazione)) e la persona responsabile del procedimento;
- c-bis) la data entro la quale, secondo i termini previsti dall'articolo 2, commi 2 o 3, deve concludersi il procedimento e i rimedi esperibili in caso di inerzia dell'amministrazione;
- c-ter) nei procedimenti ad iniziativa di parte, la data di presentazione della relativa istanza;
- d) le modalita' con le quali, attraverso il punto di accesso telematico di cui all'articolo 64-bis del decreto legislativo 7 marzo 2005, n. 82 o con altre modalita' telematiche, e' possibile prendere visione degli atti, accedere al fascicolo informatico di cui all'articolo 41 dello stesso decreto legislativo n. 82 del 2005 ed esercitare in via telematica i diritti previsti dalla presente legge;
- d-bis) l'ufficio dove e' possibile prendere visione degli atti che non sono disponibili o accessibili con le modalita' di cui alla lettera d).

3. Qualora per il numero dei destinatari la comunicazione personale non sia possibile o risulti particolarmente gravosa, l'amministrazione provvede a rendere noti gli elementi di cui al comma 2 mediante forme di pubblicita' idonee di volta in volta stabilite dall'amministrazione medesima.

4. L'omissione di taluna delle comunicazioni prescritte puo' esser fatta valere solo dal soggetto nel cui interesse la comunicazione e' prevista.

### Art. 9. - (( (Intervento nel procedimento) ))

1. Qualunque soggetto, portatore di interessi pubblici o privati, nonche' i portatori di interessi diffusi costituiti in associazioni o comitati, cui possa derivare un pregiudizio dal provvedimento, hanno facolta' di intervenire nel procedimento.

### Art. 10. - (( (Diritti dei partecipanti al procedimento) ))

1. I soggetti di cui all'articolo 7 e quelli intervenuti ai sensi dell'articolo 9 hanno diritto:

- a) di prendere visione degli atti del procedimento, salvo quanto previsto dall'articolo 24;
- b) di presentare memorie scritte e documenti, che l'amministrazione ha l'obbligo di valutare ove siano pertinenti all'oggetto del procedimento.

### Art. 10-bis. - (Comunicazione dei motivi ostativi all'accoglimento dell'istanza).

1. Nei procedimenti ad istanza di parte il responsabile del procedimento o l'autorita' competente, prima della formale adozione di un provvedimento negativo, comunica tempestivamente agli istanti i motivi che ostano all'accoglimento della domanda. Entro il termine di dieci giorni dal ricevimento della comunicazione, gli istanti hanno il diritto di presentare per iscritto le loro osservazioni, eventualmente corredate da documenti. ((La comunicazione di cui al primo periodo sospende i termini di conclusione dei procedimenti, che ricominciano a decorrere dieci giorni dopo la presentazione delle osservazioni o, in mancanza delle stesse, dalla scadenza del termine di cui al secondo periodo. Qualora gli istanti abbiano presentato osservazioni, del loro eventuale mancato accoglimento il responsabile del procedimento o l'autorita' competente sono tenuti a dare ragione nella motivazione del provvedimento finale di diniego indicando, se ve ne sono, i soli motivi ostativi ulteriori che sono conseguenza delle osservazioni. In caso di annullamento in giudizio del provvedimento cosi' adottato, nell'esercitare nuovamente il suo potere l'amministrazione non puo' addurre per la prima volta motivi ostativi gia' emergenti dall'istruttoria del provvedimento annullato.)) Le disposizioni di cui al presente articolo non si applicano alle procedure concorsuali e ai procedimenti in materia previdenziale e assistenziale sorti a seguito di istanza di parte e gestiti dagli enti previdenziali. Non possono essere addotti tra i motivi che ostano all'accoglimento della domanda inadempienze o ritardi attribuibili all'amministrazione.

### Art. 11. - (Accordi integrativi o sostitutivi del provvedimento)

1. In accoglimento di osservazioni e proposte presentate a norma dell'articolo 10, l'amministrazione procedente puo' concludere, senza pregiudizio dei diritti dei terzi, e in ogni caso nel perseguimento del pubblico interesse, accordi con gli interessati al fine di determinare il contenuto discrezionale del provvedimento finale ovvero in sostituzione di questo.

1-bis. Al fine di favorire la conclusione degli accordi di cui al comma 1, il responsabile del procedimento puo' predisporre un calendario di incontri cui invita, separatamente o contestualmente, il destinatario del provvedimento ed eventuali controinteressati.

2. Gli accordi di cui al presente articolo debbono essere stipulati, a pena di nullita' per atto scritto, salvo che la legge disponga altrimenti. Ad essi si applicano, ove non diversamente previsto, i principi del codice civile in materia di obbligazioni e contratti in quanto compatibili. ((Gli accordi di cui al presente articolo devono essere motivati ai sensi dell'articolo 3)).

3. Gli accordi sostitutivi di provvedimenti sono soggetti ai medesimi controlli previsti per questi ultimi.

4. Per sopravvenuti motivi di pubblico interesse l'amministrazione recede unilateralmente dall'accordo, salvo l'obbligo di provvedere alla liquidazione di un indennizzo in relazione agli eventuali pregiudizi verificatisi in danno del privato.

4-bis. A garanzia dell'imparzialita' e del buon andamento dell'azione amministrativa, in tutti i casi in cui una pubblica amministrazione conclude accordi nelle ipotesi previste al comma l, la stipulazione dell'accordo e' preceduta da una determinazione dell'organo che sarebbe competente per l'adozione del provvedimento.

5. COMMA ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104.

### Art. 12. - (Provvedimenti attributivi di vantaggi economici)

1. La concessione di sovvenzioni, contributi, sussidi ed ausili finanziari e l'attribuzione di vantaggi economici di qualunque genere a persone ed enti pubblici e privati sono subordinate alla predeterminazione ((...)) da parte delle amministrazioni procedenti, nelle forme previste dai rispettivi ordinamenti, dei criteri e delle modalita' cui le amministrazioni stesse devono attenersi.

2. L'effettiva osservanza dei criteri e delle modalita' di cui al comma 1 deve risultare dai singoli provvedimenti relativi agli interventi di cui al medesimo comma 1.

### Art. 13. - (( (Ambito di applicazione delle norme sulla partecipazione) ))

1. Le disposizioni contenute nel presente capo non si applicano nei confronti dell'attivita' della pubblica amministrazione diretta alla emanazione di atti normativi, amministrativi generali, di pianificazione e di programmazione, per i quali restano ferme le particolari norme che ne regolano la formazione.

2. Dette disposizioni non si applicano altresi' ai procedimenti tributari per i quali restano parimenti ferme le particolari norme che li regolano , nonche' ai procedimenti previsti dal decreto-legge 15 gennaio 1991, n. 8, convertito, con modificazioni, dalla legge 15 marzo 1991, n. 82, e successive modificazioni, e dal decreto legislativo 29 marzo 1993, n. 119, e successive modificazioni.

## SEMPLIFICAZIONE DELL'AZIONE AMMINISTRATIVA

### Art. 14. - (Conferenze di servizi)

1. La conferenza di servizi istruttoria puo' essere indetta dall'amministrazione procedente, anche su richiesta di altra amministrazione coinvolta nel procedimento o del privato interessato, quando lo ritenga opportuno per effettuare un esame contestuale degli interessi pubblici coinvolti in un procedimento amministrativo, ovvero in piu' procedimenti amministrativi connessi, riguardanti medesime attivita' o risultati. Tale conferenza si svolge con le modalita' previste dall'articolo 14-bis o con modalita' diverse, definite dall'amministrazione procedente.

2. La conferenza di servizi decisoria e' sempre indetta dall'amministrazione procedente quando la conclusione positiva del procedimento e' subordinata all'acquisizione di piu' pareri, intese, concerti, nulla osta o altri atti di assenso, comunque denominati, resi da diverse amministrazioni, inclusi i gestori di beni o servizi pubblici. Quando l'attivita' del privato sia subordinata a piu' atti di assenso, comunque denominati, da adottare a conclusione di distinti procedimenti, di competenza di diverse amministrazioni pubbliche, la conferenza di servizi e' convocata, anche su richiesta dell'interessato, da una delle amministrazioni procedenti.

3. Per progetti di particolare complessita' e di insediamenti produttivi di beni e servizi l'amministrazione procedente, su motivata richiesta dell'interessato, corredata da uno studio di fattibilita', puo' indire una conferenza preliminare finalizzata a indicare al richiedente, prima della presentazione di una istanza o di un progetto definitivo, le condizioni per ottenere, alla loro presentazione, i necessari pareri, intese, concerti, nulla osta, autorizzazioni, concessioni o altri atti di assenso, comunque denominati. L'amministrazione procedente, se ritiene di accogliere la richiesta motivata di indizione della conferenza, la indice entro cinque giorni lavorativi dalla ricezione della richiesta stessa. La conferenza preliminare si svolge secondo le disposizioni dell'articolo 14-bis, con abbreviazione dei termini fino alla meta'. Le amministrazioni coinvolte esprimono le proprie determinazioni sulla base della documentazione prodotta dall'interessato. Scaduto il termine entro il quale le amministrazioni devono rendere le proprie determinazioni, l'amministrazione procedente le trasmette, entro cinque giorni, al richiedente. Ove si sia svolta la conferenza preliminare, l'amministrazione procedente, ricevuta l'istanza o il progetto definitivo, indice la conferenza simultanea nei termini e con le modalita' di cui agli articoli 14-bis, comma 7, e 14-ter e, in sede di conferenza simultanea, le determinazioni espresse in sede di conferenza preliminare possono essere motivatamente modificate o integrate solo in presenza di significativi elementi emersi nel successivo procedimento anche a seguito delle osservazioni degli interessati sul progetto definitivo. Nelle procedure di realizzazione di opere pubbliche o di interesse pubblico, la conferenza di servizi si esprime sul progetto di fattibilita' tecnica ed economica, al fine di indicare le condizioni per ottenere, sul progetto definitivo, le intese, i pareri, le concessioni, le autorizzazioni, le licenze, i nullaosta e gli assensi, comunque denominati, richiesti dalla normativa vigente.

((4. Qualora un progetto sia sottoposto a valutazione di impatto ambientale di competenza regionale, tutte le autorizzazioni, intese, concessioni, licenze, pareri, concerti, nulla osta e assensi comunque denominati, necessari alla realizzazione e all'esercizio del medesimo progetto, vengono acquisiti nell'ambito di apposita conferenza di servizi, convocata in modalita' sincrona ai sensi dell'articolo 14-ter, secondo quanto previsto dall'articolo 27-bis del decreto legislativo 3 aprile 2006, n. 152.))

((40))

5. L'indizione della conferenza e' comunicata ai soggetti di cui all'articolo 7, i quali possono intervenire nel procedimento ai sensi dell'articolo 9.

-------------- AGGIORNAMENTO (40) Il D.Lgs. 16 giugno 2017, n. 104 ha disposto (con l'art. 23, comma 1) che "Le disposizioni del presente decreto si applicano ai procedimenti di verifica di assoggettabilita' a VIA e ai procedimenti di VIA avviati dal 16 maggio 2017". Ha inoltre disposto (con l'art. 23, comma 2) che "I procedimenti di verifica di assoggettabilita' a VIA pendenti alla data del 16 maggio 2017, nonche' i procedimenti di VIA per i progetti per i quali alla medesima data risulti avviata la fase di consultazione di cui all'articolo 21 del decreto legislativo 3 aprile 2006, n. 152, ovvero sia stata presentata l'istanza di cui all'articolo 23 del medesimo decreto legislativo, restano disciplinati dalla normativa previgente".

### Art. 14-bis. - (( (Conferenza semplificata).))

((

1. La conferenza decisoria di cui all'articolo 14, comma 2, si svolge in forma semplificata e in modalita' asincrona, salvo i casi di cui ai commi 6 e 7. Le comunicazioni avvengono secondo le modalita' previste dall'articolo 47 del decreto legislativo 7 marzo 2005, n. 82.

2. La conferenza e' indetta dall'amministrazione procedente entro cinque giorni lavorativi dall'inizio del procedimento d'ufficio o dal ricevimento della domanda, se il procedimento e' ad iniziativa di parte. A tal fine l'amministrazione procedente comunica alle altre amministrazioni interessate:

- a) l'oggetto della determinazione da assumere, l'istanza e la relativa documentazione ovvero le credenziali per l'accesso telematico alle informazioni e ai documenti utili ai fini dello svolgimento dell'istruttoria;
- b) il termine perentorio, non superiore a quindici giorni, entro il quale le amministrazioni coinvolte possono richiedere, ai sensi dell'articolo 2, comma 7, integrazioni documentali o chiarimenti relativi a fatti, stati o qualita' non attestati in documenti gia' in possesso dell'amministrazione stessa o non direttamente acquisibili presso altre pubbliche amministrazioni;
- c) il termine perentorio, comunque non superiore a quarantacinque giorni, entro il quale le amministrazioni coinvolte devono rendere le proprie determinazioni relative alla decisione oggetto della conferenza, fermo restando l'obbligo di rispettare il termine finale di conclusione del procedimento. Se tra le suddette amministrazioni vi sono amministrazioni preposte alla tutela ambientale, paesaggistico-territoriale, dei beni culturali, o alla tutela della salute dei cittadini, ove disposizioni di legge o i provvedimenti di cui all'articolo 2 non prevedano un termine diverso, il suddetto termine e' fissato in novanta giorni;
- d) la data della eventuale riunione in modalita' sincrona di cui all'articolo 14-ter, da tenersi entro dieci giorni dalla scadenza del termine di cui alla lettera c), fermo restando l'obbligo di rispettare il termine finale di conclusione del procedimento.

3. Entro il termine di cui al comma 2, lettera c), le amministrazioni coinvolte rendono le proprie determinazioni, relative alla decisione oggetto della conferenza. Tali determinazioni, congruamente motivate, sono formulate in termini di assenso o dissenso e indicano, ove possibile, le modifiche eventualmente necessarie ai fini dell'assenso. Le prescrizioni o condizioni eventualmente indicate ai fini dell'assenso o del superamento del dissenso sono espresse in modo chiaro e analitico e specificano se sono relative a un vincolo derivante da una disposizione normativa o da un atto amministrativo generale ovvero discrezionalmente apposte per la migliore tutela dell'interesse pubblico.

4. Fatti salvi i casi in cui disposizioni del diritto dell'Unione europea richiedono l'adozione di provvedimenti espressi, la mancata comunicazione della determinazione entro il termine di cui al comma 2, lettera c), ovvero la comunicazione di una determinazione priva dei requisiti previsti dal comma 3, equivalgono ad assenso senza condizioni. Restano ferme le responsabilita' dell'amministrazione, nonche' quelle dei singoli dipendenti nei confronti dell'amministrazione, per l'assenso reso, ancorche' implicito.

5. Scaduto il termine di cui al comma 2, lettera c), l'amministrazione procedente adotta, entro cinque giorni lavorativi, la determinazione motivata di conclusione positiva della conferenza, con gli effetti di cui all'articolo 14-quater, qualora abbia acquisito esclusivamente atti di assenso non condizionato, anche implicito, ovvero qualora ritenga, sentiti i privati e le altre amministrazioni interessate, che le condizioni e prescrizioni eventualmente indicate dalle amministrazioni ai fini dell'assenso o del superamento del dissenso possano essere accolte senza necessita' di apportare modifiche sostanziali alla decisione oggetto della conferenza. Qualora abbia acquisito uno o piu' atti di dissenso che non ritenga superabili, l'amministrazione procedente adotta, entro il medesimo termine, la determinazione di conclusione negativa della conferenza che produce l'effetto del rigetto della domanda. Nei procedimenti a istanza di parte la suddetta determinazione produce gli effetti della comunicazione di cui all'articolo 10-bis. L'amministrazione procedente trasmette alle altre amministrazioni coinvolte le eventuali osservazioni presentate nel termine di cui al suddetto articolo e procede ai sensi del comma 2. Dell'eventuale mancato accoglimento di tali osservazioni e' data ragione nell'ulteriore determinazione di conclusione della conferenza. 6.Fuori dei casi di cui al comma 5, l'amministrazione procedente, ai fini dell'esame contestuale degli interessi coinvolti, svolge, nella data fissata ai sensi del comma 2, lettera d), la riunione della conferenza in modalita' sincrona, ai sensi dell'articolo 14-ter. 7. Ove necessario, in relazione alla particolare complessita' della determinazione da assumere, l'amministrazione procedente puo' comunque procedere direttamente in forma simultanea e in modalita' sincrona, ai sensi dell'articolo 14-ter. In tal caso indice la conferenza comunicando alle altre amministrazioni le informazioni di cui alle lettere a) e b) del comma 2 e convocando la riunione entro i successivi quarantacinque giorni. L'amministrazione procedente puo' altresi' procedere in forma simultanea e in modalita' sincrona su richiesta motivata delle altre amministrazioni o del privato interessato avanzata entro il termine perentorio di cui al comma 2, lettera b). In tal caso la riunione e' convocata nei successivi quarantacinque giorni 2.))

((38))

---------- AGGIORNAMENTO (38) Il D.Lgs. 30 giugno 2016, n. 127 ha disposto (con l'art. 6, comma 1) che "Nel caso di conferenza di servizi indetta per interventi che richiedono l'autorizzazione paesaggistica, l'amministrazione procedente effettua la comunicazione di cui all'articolo 14-bis della legge 7 agosto 1990, n. 241, come modificato dal presente decreto, sia all'amministrazione competente al rilascio dell'autorizzazione, se diversa dall'amministrazione procedente, sia al soprintendente che deve esprimere il parere di cui all'articolo 146 del decreto legislativo 22 gennaio 2004, n. 42".

### Art. 14-ter. - (( (Conferenza simultanea).))

((

1. La prima riunione della conferenza di servizi in forma simultanea e in modalita' sincrona si svolge nella data previamente comunicata ai sensi dell'articolo 14-bis, comma 2, lettera d), ovvero nella data fissata ai sensi dell'articolo 14-bis, comma 7, con la partecipazione contestuale, ove possibile anche in via telematica, dei rappresentanti delle amministrazioni competenti.

2. I lavori della conferenza si concludono non oltre quarantacinque giorni decorrenti dalla data della riunione di cui al comma 1. Nei casi di cui all'articolo 14-bis, comma 7, qualora siano coinvolte amministrazioni preposte alla tutela ambientale, paesaggistico-territoriale, dei beni culturali e della salute dei cittadini, il termine e' fissato in novanta giorni. Resta fermo l'obbligo di rispettare il termine finale di conclusione del procedimento.

3. Ciascun ente o amministrazione convocato alla riunione e' rappresentato da un unico soggetto abilitato ad esprimere definitivamente e in modo univoco e vincolante la posizione dell'amministrazione stessa su tutte le decisioni di competenza della conferenza, anche indicando le modifiche progettuali eventualmente necessarie ai fini dell'assenso.

4. Ove alla conferenza partecipino anche amministrazioni non statali, le amministrazioni statali sono rappresentate da un unico soggetto abilitato ad esprimere definitivamente in modo univoco e vincolante la posizione di tutte le predette amministrazioni, nominato, anche preventivamente per determinate materie o determinati periodi di tempo, dal Presidente del Consiglio dei ministri, ovvero, ove si tratti soltanto di amministrazioni periferiche, dal Prefetto. Ferma restando l'attribuzione del potere di rappresentanza al suddetto soggetto, le singole amministrazioni statali possono comunque intervenire ai lavori della conferenza in funzione di supporto. Le amministrazioni di cui all'articolo 14-quinquies, comma 1, prima della conclusione dei lavori della conferenza, possono esprimere al suddetto rappresentante il proprio dissenso ai fini di cui allo stesso comma.

5. Ciascuna regione e ciascun ente locale definisce autonomamente le modalita' di designazione del rappresentante unico di tutte le amministrazioni riconducibili alla stessa regione o allo stesso ente locale nonche' l'eventuale partecipazione delle suddette amministrazioni ai lavori della conferenza.

6. Alle riunioni della conferenza possono essere invitati gli interessati, inclusi i soggetti proponenti il progetto eventualmente dedotto in conferenza.

7. All'esito dell'ultima riunione, e comunque non oltre il termine di cui al comma 2, l'amministrazione procedente adotta la determinazione motivata di conclusione della conferenza, con gli effetti di cui all'articolo 14-quater, sulla base delle posizioni prevalenti espresse dalle amministrazioni partecipanti alla conferenza tramite i rispettivi rappresentanti. Si considera acquisito l'assenso senza condizioni delle amministrazioni il cui rappresentante non abbia partecipato alle riunioni ovvero, pur partecipandovi, non abbia espresso ai sensi del comma 3 la propria posizione, ovvero abbia espresso un dissenso non motivato o riferito a questioni che non costituiscono oggetto della conferenza.))

--------------- AGGIORNAMENTO (33) Il D.L. 12 settembre 2014, n. 133 convertito con modificazioni dalla L. 11 novembre 2014, n. 164 ha disposto (con l'art. 4, comma 1) che "Al fine di favorire la realizzazione delle opere segnalate dai Comuni alla Presidenza del Consiglio dei Ministri dal 2 al 15 giugno 2014 e di quelle inserite nell'elenco-anagrafe di cui all'articolo 44-bis del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, per le quali la problematica emersa attenga al mancato concerto tra Amministrazioni interessate al procedimento amministrativo, e' data facolta' di riconvocare la Conferenza di Servizi, ancorche' gia' definita in precedenza, funzionale al riesame dei pareri ostativi alla realizzazione dell'opera. Ove l'Ente proceda ad una riconvocazione, i termini di cui all'articolo 14-ter, della legge 7 agosto 1990, n. 241, sono ridotti alla meta'".

### Art. 14-quater. - (( (Decisione della conferenza di servizi).))

((

1. La determinazione motivata di conclusione della conferenza, adottata dall'amministrazione procedente all'esito della stessa, sostituisce a ogni effetto tutti gli atti di assenso, comunque denominati, di competenza delle amministrazioni e dei gestori di beni o servizi pubblici interessati.

2. Le amministrazioni i cui atti sono sostituiti dalla determinazione motivata di conclusione della conferenza possono sollecitare con congrua motivazione l'amministrazione procedente ad assumere, previa indizione di una nuova conferenza, determinazioni in via di autotutela ai sensi dell'articolo 21-nonies. Possono altresi' sollecitarla, purche' abbiano partecipato, anche per il tramite del rappresentante di cui ai commi 4 e 5 dell'articolo 14-ter, alla conferenza di servizi o si siano espresse nei termini, ad assumere determinazioni in via di autotutela ai sensi dell'articolo 21-quinquies.

3. In caso di approvazione unanime, la determinazione di cui al comma 1 e' immediatamente efficace. In caso di approvazione sulla base delle posizioni prevalenti, l'efficacia della determinazione e' sospesa ove siano stati espressi dissensi qualificati ai sensi dell'articolo 14-quinquies e per il periodo utile all'esperimento dei rimedi ivi previsti.

4. I termini di efficacia di tutti i pareri, autorizzazioni, concessioni, nulla osta o atti di assenso comunque denominati acquisiti nell'ambito della conferenza di servizi decorrono dalla data della comunicazione della determinazione motivata di conclusione della conferenza.))

------------- AGGIORNAMENTO (26) Successivamente la Corte Costituzionale, con sentenza 2 - 11 luglio 2012, n. 179 (in G.U. 1a s.s. 18/7/2012, n. 29), ha dichiarato l'illegittimita' costituzionale dell'art. 49, comma 3, lettera b), del decreto-legge 31 maggio 2010, n. 78, convertito con modificazioni dalla L. 30 luglio 2010, n. 122, (che ha modificato il comma 3 del presente articolo) "nella parte in cui prevede che, in caso di dissenso espresso in sede di conferenza di servizi da una Regione o da una Provincia autonoma, in una delle materie di propria competenza, ove non sia stata raggiunta, entro il breve termine di trenta giorni, l'intesa, «il Consiglio dei ministri delibera in esercizio del proprio potere sostitutivo con la partecipazione dei Presidenti delle Regioni o delle Province autonome interessate»".

### Art. 14-quinquies. - (( (Rimedi per le amministrazioni dissenzienti). ))

((

1. Avverso la determinazione motivata di conclusione della conferenza, entro 10 giorni dalla sua comunicazione, le amministrazioni preposte alla tutela ambientale, paesaggistico-territoriale, dei beni culturali o alla tutela della salute e della pubblica incolumita' dei cittadini possono proporre opposizione al Presidente del Consiglio dei ministri a condizione che abbiano espresso in modo inequivoco il proprio motivato dissenso prima della conclusione dei lavori della conferenza. Per le amministrazioni statali l'opposizione e' proposta dal Ministro competente.

2. Possono altresi' proporre opposizione le amministrazioni delle regioni o delle province autonome di Trento e di Bolzano, il cui rappresentante, intervenendo in una materia spettante alla rispettiva competenza, abbia manifestato un dissenso motivato in seno alla conferenza.

3. La proposizione dell'opposizione sospende l'efficacia della determinazione motivata di conclusione della conferenza.

4. La Presidenza del Consiglio dei ministri indice, per una data non posteriore al quindicesimo giorno successivo alla ricezione dell'opposizione, una riunione con la partecipazione delle amministrazioni che hanno espresso il dissenso e delle altre amministrazioni che hanno partecipato alla conferenza. In tale riunione i partecipanti formulano proposte, in attuazione del principio di leale collaborazione, per l'individuazione di una soluzione condivisa, che sostituisca la determinazione motivata di conclusione della conferenza con i medesimi effetti.

5. Qualora alla conferenza di servizi abbiano partecipato amministrazioni delle regioni o delle province autonome di Trento e di Bolzano, e l'intesa non venga raggiunta nella riunione di cui al comma 4, puo' essere indetta, entro i successivi quindici giorni, una seconda riunione, che si svolge con le medesime modalita' e allo stesso fine.

6. Qualora all'esito delle riunioni di cui ai commi 4 e 5 sia raggiunta un'intesa tra le amministrazioni partecipanti, l'amministrazione procedente adotta una nuova determinazione motivata di conclusione della conferenza. Qualora all'esito delle suddette riunioni, e comunque non oltre quindici giorni dallo svolgimento della riunione, l'intesa non sia raggiunta, la questione e' rimessa al Consiglio dei ministri. La questione e' posta, di norma, all'ordine del giorno della prima riunione del Consiglio dei ministri successiva alla scadenza del termine per raggiungere l'intesa. Alla riunione del Consiglio dei ministri possono partecipare i Presidenti delle regioni o delle province autonome interessate. Qualora il Consiglio dei ministri non accolga l'opposizione, la determinazione motivata di conclusione della conferenza acquisisce definitivamente efficacia. Il Consiglio dei ministri puo' accogliere parzialmente l'opposizione, modificando di conseguenza il contenuto della determinazione di conclusione della conferenza, anche in considerazione degli esiti delle riunioni di cui ai commi 4 e 5. 7.Restano ferme le attribuzioni e le prerogative riconosciute alle regioni a statuto speciale e alle province autonome di Trento e Bolzano dagli statuti speciali di autonomia e dalle relative norme di attuazione.

))

### Art. 15. - (Accordi fra pubbliche amministrazioni)

1. Anche al di fuori delle ipotesi previste dall'articolo 14, le amministrazioni pubbliche possono sempre concludere tra loro accordi per disciplinare lo svolgimento in collaborazione di attivita' di interesse comune.

2. Per detti accordi si osservano, in quanto applicabili, le disposizioni previste dall'articolo 11, commi 2 e 3.

2-bis. A fare data dal ((30 giugno 2014)) gli accordi di cui al comma 1 sono sottoscritti con firma digitale, ai sensi dell'articolo 24 del decreto legislativo 7 marzo 2005, n. 82, con firma elettronica avanzata, ai sensi dell'articolo 1, comma 1, lettera q-bis), del decreto legislativo 7 marzo 2005, n. 82, ovvero con altra firma elettronica qualificata, pena la nullita' degli stessi. Dall'attuazione della presente disposizione non devono derivare nuovi o maggiori oneri a carico del bilancio dello Stato. All'attuazione della medesima si provvede nell'ambito delle risorse umane, strumentali e finanziarie previste dalla legislazione vigente. (30) ((31))

-------------- AGGIORNAMENTO (30) Il D.L. 12 settembre 2013, n. 104, convertito con modificazioni dalla L. 8 novembre 2013, n. 128 ha disposto (con l'art. 10-ter, comma 1) che "Le convenzioni relative ai programmi straordinari stralcio di interventi urgenti sul patrimonio scolastico finalizzati alla messa in sicurezza e alla prevenzione e riduzione del rischio connesso alla vulnerabilita' degli elementi, anche non strutturali, degli edifici scolastici, di cui alle deliberazioni del Comitato interministeriale per la programmazione economica n. 32 del 13 maggio 2010, pubblicata nel supplemento ordinario n. 216 alla Gazzetta Ufficiale n. 215 del 14 settembre 2010, e n. 6 del 20 gennaio 2012, pubblicata nella Gazzetta Ufficiale n. 88 del 14 aprile 2012, in deroga a quanto disposto dall'articolo 15, comma 2-bis, della legge 7 agosto 1990, n. 241, possono essere sottoscritte in forma olografa fino al 30 giugno 2014". -------------- AGGIORNAMENTO (31) Il D.L. 23 dicembre 2013, n. 145, convertito con modificazioni dalla L. 21 febbraio 2014, n. 9 ha disposto (con l'art. 6, comma 7) che sono validi gli accordi di cui al presente articolo, comma 2-bis, non stipulati in modalita' elettronica a far data dal 1° gennaio 2013 e fino alla data in cui la stipula in modalita' elettronica diventa obbligatoria ai sensi del comma 2-bis del presente articolo.

### Art. 16. - (Attivita' consultiva)

1. Gli organi consultivi delle pubbliche amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 3 febbraio 1993, n. 29, sono tenuti a rendere i pareri ad essi obbligatoriamente richiesti entro venti giorni dal ricevimento della richiesta. Qualora siano richiesti di pareri facoltativi, sono tenuti a dare immediata comunicazione alle amministrazioni richiedenti del termine entro il quale il parere sara' reso, che comunque non puo' superare i venti giorni dal ricevimento della richiesta.

2. ((PERIODO SOPPRESSO DAL D.L. 16 LUGLIO 2020, N. 76)). In caso di decorrenza del termine senza che sia stato comunicato il parere ((...)) o senza che l'organo adito abbia rappresentato esigenze istruttorie, l'amministrazione richiedente procede indipendentemente dall'espressione del parere. Salvo il caso di omessa richiesta del parere, il responsabile del procedimento non puo' essere chiamato a rispondere degli eventuali danni derivanti dalla mancata espressione dei pareri di cui al presente comma.

3. Le disposizioni di cui ai commi 1 e 2 non si applicano in caso di pareri che debbano essere rilasciati da amministrazioni preposte alla tutela ambientale, paesaggistica, territoriale e della salute dei cittadini.

4. Nel caso in cui l'organo adito abbia rappresentato esigenze istruttorie, i termini di cui al comma 1 possono essere interrotti per una sola volta e il parere deve essere reso definitivamente entro quindici giorni dalla ricezione degli elementi istruttori da parte delle amministrazioni interessate.

5. I pareri di cui al comma 1 sono trasmessi con mezzi telematici.

6. Gli organi consultivi dello Stato predispongono procedure di particolare urgenza per l'adozione dei pareri loro richiesti.

6-bis. Resta fermo quanto previsto dall'articolo 127 del codice dei contratti pubblici relativi a lavori, servizi e forniture, di cui al decreto legislativo 12 aprile 2006, n. 163, e successive modificazioni.

### Art. 17. - (( (Valutazioni tecniche) ))

1. Ove per disposizione espressa di legge o di regolamento sia previsto che per l'adozione di un provvedimento debbano essere preventivamente acquisite le valutazioni tecniche di organi od enti appositi e tali organi ed enti non provvedano o non rappresentino esigenze istruttorie di competenza dell'amministrazione procedente nei termini prefissati dalla disposizione stessa o, in mancanza, entro novanta giorni dal ricevimento della richiesta, il responsabile del procedimento deve chiedere le suddette valutazioni tecniche ad altri organi dell'amministrazione pubblica o ad enti pubblici che siano dotati di qualificazione e capacita' tecnica equipollenti, ovvero ad istituti universitari.

2. La disposizione di cui al comma 1 non si applica in caso di valutazioni che debbano essere prodotte da amministrazioni preposte alla tutela ambientale, paessaggistico-territoriale e della salute dei cittadini.

3. Nel caso in cui l'ente od organo adito abbia rappresentato esigenze istruttorie all'amministrazione procedente, si applica quanto previsto dal comma 4 dell'articolo 16.

### Art. 17-bis.

( ((Effetti del silenzio e dell'inerzia nei rapporti)) tra amministrazioni pubbliche e tra amministrazioni pubbliche e gestori di beni o servizi pubblici).

1. Nei casi in cui e' prevista l'acquisizione di assensi, concerti o nulla osta comunque denominati di amministrazioni pubbliche e di gestori di beni o servizi pubblici, per l'adozione di provvedimenti normativi e amministrativi di competenza di altre amministrazioni pubbliche, le amministrazioni o i gestori competenti comunicano il proprio assenso, concerto o nulla osta entro trenta giorni dal ricevimento dello schema di provvedimento, corredato della relativa documentazione, da parte dell'amministrazione procedente. ((Esclusi i casi di cui al comma 3, quando per l'adozione di provvedimenti normativi e amministrativi e' prevista la proposta di una o piu' amministrazioni pubbliche diverse da quella competente ad adottare l'atto, la proposta stessa e' trasmessa entro trenta giorni dal ricevimento della richiesta da parte di quest'ultima amministrazione.)) Il termine e' interrotto qualora l'amministrazione o il gestore che deve rendere il proprio assenso, concerto o nulla osta rappresenti esigenze istruttorie o richieste di modifica, motivate e formulate in modo puntuale nel termine stesso. In tal caso, l'assenso, il concerto o il nulla osta e' reso nei successivi trenta giorni dalla ricezione degli elementi istruttori o dello schema di provvedimento; ((lo stesso termine si applica qualora dette esigenze istruttorie siano rappresentate dall'amministrazione proponente nei casi di cui al secondo periodo.)) ((Non sono ammesse)) ulteriori interruzioni di termini.

2. Decorsi i termini di cui al comma 1 senza che sia stato comunicato l'assenso, il concerto o il nulla osta, lo stesso si intende acquisito. ((Esclusi i casi di cui al comma 3, qualora la proposta non sia trasmessa nei termini di cui al comma 1, secondo periodo, l'amministrazione competente puo' comunque procedere. In tal caso, lo schema di provvedimento, corredato della relativa documentazione, e' trasmesso all'amministrazione che avrebbe dovuto formulare la proposta per acquisirne l'assenso ai sensi del presente articolo.)) In caso di mancato accordo tra le amministrazioni statali coinvolte nei procedimenti di cui al comma 1, il Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri, decide sulle modifiche da apportare allo schema di provvedimento.

3. Le disposizioni dei commi 1 e 2 si applicano anche ai casi in cui e' prevista l'acquisizione di assensi, concerti o nulla osta comunque denominati di amministrazioni preposte alla tutela ambientale, paesaggistico-territoriale, dei beni culturali e della salute dei cittadini, per l'adozione di provvedimenti normativi e amministrativi di competenza di amministrazioni pubbliche. In tali casi, ove disposizioni di legge o i provvedimenti di cui all'articolo 2 non prevedano un termine diverso, il termine entro il quale le amministrazioni competenti comunicano il proprio assenso, concerto o nulla osta e' di novanta giorni dal ricevimento della richiesta da parte dell'amministrazione procedente. Decorsi i suddetti termini senza che sia stato comunicato l'assenso, il concerto o il nulla osta, lo stesso si intende acquisito.

4. Le disposizioni del presente articolo non si applicano nei casi in cui disposizioni del diritto dell'Unione europea richiedano l'adozione di provvedimenti espressi.

### Art. 18. - (Autocertificazione)

1. ((Le amministrazioni)) adottano le misure organizzative idonee a garantire l'applicazione delle disposizioni in materia di autocertificazione e di presentazione di atti e documenti da parte di cittadini a pubbliche amministrazioni ((di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445)). PERIODO SOPPRESSO DAL D.P.R. 2 AGOSTO 2007, N. 157.

2. I documenti attestanti atti, fatti, qualita' e stati soggettivi, necessari per l'istruttoria del procedimento, sono acquisiti d'ufficio quando sono in possesso dell'amministrazione procedente, ovvero sono detenuti, istituzionalmente, da altre pubbliche amministrazioni. L'amministrazione procedente puo' richiedere agli interessati i soli elementi necessari per la ricerca dei documenti.

3. Parimenti sono accertati d'ufficio dal responsabile del procedimento i fatti, gli stati e le qualita' che la stessa amministrazione procedente o altra pubblica amministrazione e' tenuta a certificare.

((

3-bis. Nei procedimenti avviati su istanza di parte, che hanno ad oggetto l'erogazione di benefici economici comunque denominati, indennita', prestazioni previdenziali e assistenziali, erogazioni, contributi, sovvenzioni, finanziamenti, prestiti, agevolazioni, da parte di pubbliche amministrazioni ovvero il rilascio di autorizzazioni e nulla osta comunque denominati, le dichiarazioni di cui agli articoli 46 e 47 del decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, ovvero l'acquisizione di dati e documenti di cui ai commi 2 e 3, sostituiscono ogni tipo di documentazione comprovante tutti i requisiti soggettivi ed oggettivi richiesti dalla normativa di riferimento, fatto comunque salvo il rispetto delle disposizioni del codice delle leggi antimafia e delle misure di prevenzione, di cui al decreto legislativo 6 settembre 2011, n. 159.

))

### Art. 18-bis. - (( (Presentazione di istanze, segnalazioni o comunicazioni).))

((

1. Dell'avvenuta presentazione di istanze, segnalazioni o comunicazioni e' rilasciata immediatamente, anche in via telematica, una ricevuta, che attesta l'avvenuta presentazione dell'istanza, della segnalazione e della comunicazione e indica i termini entro i quali l'amministrazione e' tenuta, ove previsto, a rispondere, ovvero entro i quali il silenzio dell'amministrazione equivale ad accoglimento dell'istanza. Se la ricevuta contiene le informazioni di cui all'articolo 8, essa costituisce comunicazione di avvio del procedimento ai sensi dell'articolo 7. La data di protocollazione dell'istanza, segnalazione o comunicazione non puo' comunque essere diversa da quella di effettiva presentazione. Le istanze, segnalazioni o comunicazioni producono effetti anche in caso di mancato rilascio della ricevuta, ferma restando la responsabilita' del soggetto competente.

2. Nel caso di istanza, segnalazione o comunicazione presentate ad un ufficio diverso da quello competente, i termini di cui agli articoli 19, comma 3, e 20, comma 1, decorrono dal ricevimento dell'istanza, segnalazione o della comunicazione da parte dell'ufficio competente.

))

### Art. 19. - (Segnalazione certificata di inizio attivita' - Scia)

1. Ogni atto di autorizzazione, licenza, concessione non costitutiva, permesso o nulla osta comunque denominato, comprese le domande per le iscrizioni in albi o ruoli richieste per l'esercizio di attivita' imprenditoriale, commerciale o artigianale il cui rilascio dipenda esclusivamente dall'accertamento di requisiti e presupposti richiesti dalla legge o da atti amministrativi a contenuto generale, e non sia previsto alcun limite o contingente complessivo o specifici strumenti di programmazione settoriale per il rilascio degli atti stessi, e' sostituito da una segnalazione dell'interessato, con la sola esclusione dei casi in cui sussistano vincoli ambientali, paesaggistici o culturali e degli atti rilasciati dalle amministrazioni preposte alla difesa nazionale, alla pubblica sicurezza, all'immigrazione, all'asilo, alla cittadinanza, all'amministrazione della giustizia, all'amministrazione delle finanze, ivi compresi gli atti concernenti le reti di acquisizione del gettito, anche derivante dal gioco, nonche' di quelli previsti dalla normativa per le costruzioni in zone sismiche e di quelli imposti dalla normativa comunitaria. La segnalazione e' corredata dalle dichiarazioni sostitutive di certificazioni e dell'atto di notorieta' per quanto riguarda tutti gli stati, le qualita' personali e i fatti previsti negli articoli 46 e 47 del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, nonche' , ove espressamente previsto dalla normativa vigente, dalle attestazioni e asseverazioni di tecnici abilitati, ovvero dalle dichiarazioni di conformita' da parte dell'Agenzia delle imprese di cui all'articolo 38, comma 4, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, relative alla sussistenza dei requisiti e dei presupposti di cui al primo periodo; tali attestazioni e asseverazioni sono corredate dagli elaborati tecnici necessari per consentire le verifiche di competenza dell'amministrazione. Nei casi in cui la normativa vigente prevede l'acquisizione di atti o pareri di organi o enti appositi, ovvero l'esecuzione di verifiche preventive, essi sono comunque sostituiti dalle autocertificazioni, attestazioni e asseverazioni o certificazioni di cui al presente comma, salve le verifiche successive degli organi e delle amministrazioni competenti. La segnalazione, corredata delle dichiarazioni, attestazioni e asseverazioni nonche' dei relativi elaborati tecnici, puo' essere presentata mediante posta raccomandata con avviso di ricevimento, ad eccezione dei procedimenti per cui e' previsto l'utilizzo esclusivo della modalita' telematica; in tal caso la segnalazione si considera presentata al momento della ricezione da parte dell'amministrazione.

2. L'attivita' oggetto della segnalazione puo' essere iniziata, anche nei casi di cui all'articolo 19-bis, comma 2, dalla data della presentazione della segnalazione all'amministrazione competente.

3. L'amministrazione competente, in caso di accertata carenza dei requisiti e dei presupposti di cui al comma 1, nel termine di sessanta giorni dal ricevimento della segnalazione di cui al medesimo comma, adotta motivati provvedimenti di divieto di prosecuzione dell'attivita' e di rimozione degli eventuali effetti dannosi di essa. Qualora sia possibile conformare l'attivita' intrapresa e i suoi effetti alla normativa vigente, l'amministrazione competente, con atto motivato, invita il privato a provvedere prescrivendo le misure necessarie con la fissazione di un termine non inferiore a trenta giorni per l'adozione di queste ultime. In difetto di adozione delle misure da parte del privato, decorso il suddetto termine, l'attivita' si intende vietata. Con lo stesso atto motivato, in presenza di attestazioni non veritiere o di pericolo per la tutela dell'interesse pubblico in materia di ambiente, paesaggio, beni culturali, salute, sicurezza pubblica o difesa nazionale, l'amministrazione dispone la sospensione dell'attivita' intrapresa. L'atto motivato interrompe il termine di cui al primo periodo, che ricomincia a decorrere dalla data in cui il privato comunica l'adozione delle suddette misure. In assenza di ulteriori provvedimenti, decorso lo stesso termine, cessano gli effetti della sospensione eventualmente adottata.

4. Decorso il termine per l'adozione dei provvedimenti di cui al comma 3, primo periodo, ovvero di cui al comma 6-bis, l'amministrazione competente adotta comunque i provvedimenti previsti dal medesimo comma 3 in presenza delle condizioni previste dall'articolo 21-nonies.((41))

4-bis. Il presente articolo non si applica alle attivita' economiche a prevalente carattere finanziario, ivi comprese quelle regolate dal testo unico delle leggi in materia bancaria e creditizia di cui al decreto legislativo 1° settembre 1993, n. 385, e dal testo unico in materia di intermediazione finanziaria di cui al decreto legislativo 24 febbraio 1998, n. 58.

5. COMMA ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104.

6. Ove il fatto non costituisca piu' grave reato, chiunque, nelle dichiarazioni o attestazioni o asseverazioni che corredano la segnalazione di inizio attivita', dichiara o attesta falsamente l'esistenza dei requisiti o dei presupposti di cui al comma 1 e' punito con la reclusione da uno a tre anni.

6-bis. Nei casi di Scia in materia edilizia, il termine di sessanta giorni di cui al primo periodo del comma 3 e' ridotto a trenta giorni. Fatta salva l'applicazione delle disposizioni di cui al comma 4 e al comma 6, restano altresi' ferme le disposizioni relative alla vigilanza sull'attivita' urbanistico-edilizia, alle responsabilita' e alle sanzioni previste dal decreto del Presidente della Repubblica 6 giugno 2001, n.380, e dalle leggi regionali.(19)

6-ter. La segnalazione certificata di inizio attivita', la denuncia e la dichiarazione di inizio attivita' non costituiscono provvedimenti taciti direttamente impugnabili. Gli interessati possono sollecitare l'esercizio delle verifiche spettanti all'amministrazione e, in caso di inerzia, esperire esclusivamente l'azione di cui all'art. 31, commi 1, 2 e 3 del decreto legislativo 2 luglio 2010, n. 104.

------------- AGGIORNAMENTO (1a) Il D.P.R. 26 aprile 1992, n. 300 ha disposto: (con l'art. 3, comma 1) che il termine di cui al comma 2, del presente articolo decorre dalla data di ricevimento della denuncia o della domanda del privato. (con l'art. 3, comma 3) che "Qualora la denuncia o la domanda del privato non siano regolari o complete, l'amministrazione ne da' comunicazione al richiedente entro dieci giorni, indicando le cause di irregolarita' o di incompletezza. In questi casi, il termine di cui al comma 1 decorre dal ricevimento della denuncia o della domanda regolari". (con l'art. 3, comma 4) che "Nel caso in cui l'amministrazione non provveda alla comunicazione di cui al comma 3, il termine del procedimento decorre comunque dal ricevimento della denuncia o della domanda." ------------- AGGIORNAMENTO (19) Il D.L. 13 maggio 2011, n. 70, convertito con modificazioni dalla L. 12 luglio 2011, n. 106, ha disposto (con l'art. 5, comma 2, lettera c)) che "Le disposizioni di cui all'articolo 19 della legge 7 agosto 1990, n. 241 si interpretano nel senso che le stesse si applicano alle denunce di inizio attivita' in materia edilizia disciplinate dal decreto del Presidente della Repubblica 6 giugno 2001, n.380, con esclusione dei casi in cui le denunce stesse, in base alla normativa statale o regionale, siano alternative o sostitutive del permesso di costruire. Le disposizioni di cui all'articolo 19 della legge 7 agosto 1990, n. 241 si interpretano altresi' nel senso che non sostituiscono la disciplina prevista dalle leggi regionali che, in attuazione dell'articolo 22, comma 4, del decreto del Presidente della Repubblica 6 giugno 2001, n. 380, abbiano ampliato l'ambito applicativo delle disposizioni di cui all'articolo 22, comma 3, del medesimo decreto e nel senso che, nei casi in cui sussistano vincoli ambientali, paesaggistici o culturali, la Scia non sostituisce gli atti di autorizzazione o nulla osta, comunque denominati, delle amministrazioni preposte alla tutela dell'ambiente e del patrimonio culturale." ------------- AGGIORNAMENTO (41) Il D.L 19 maggio 2020, n. 34, ha disposto (con l'art. 264, comma 1 lettera c) che "Al fine di garantire la massima semplificazione, l'accelerazione dei procedimenti amministrativi e la rimozione di ogni ostacolo burocratico nella vita dei cittadini e delle imprese in relazione all'emergenza COVID-19, dalla data di entrata in vigore del presente decreto e fino al 31 dicembre 2020: [...] c) qualora l'attivita' in relazione all'emergenza Covid-19 sia iniziata sulla base di una segnalazione certificata di cui agli artt. 19 e seguenti della legge 7 agosto 1990, n. 241, il termine per l'adozione dei provvedimenti previsti dal comma 4 del medesimo art. 19 e' di tre mesi e decorre dalla scadenza del termine per l'adozione dei provvedimenti di cui al comma 3 del medesimo articolo 19;".

### Art. 19-bis. - (( (Concentrazione dei regimi amministrativi).))

((

1. Sul sito istituzionale di ciascuna amministrazione e' indicato lo sportello unico, di regola telematico, al quale presentare la SCIA, anche in caso di procedimenti connessi di competenza di altre amministrazioni ovvero di diverse articolazioni interne dell'amministrazione ricevente. Possono essere istituite piu' sedi di tale sportello, al solo scopo di garantire la pluralita' dei punti di accesso sul territorio.

2. Se per lo svolgimento di un'attivita' soggetta a SCIA sono necessarie altre SCIA, comunicazioni, attestazioni, asseverazioni e notifiche, l'interessato presenta un'unica SCIA allo sportello di cui al comma 1. L'amministrazione che riceve la SCIA la trasmette immediatamente alle altre amministrazioni interessate al fine di consentire, per quanto di loro competenza, il controllo sulla sussistenza dei requisiti e dei presupposti per lo svolgimento dell'attivita' e la presentazione, almeno cinque giorni prima della scadenza dei termini di cui all'articolo 19, commi 3 e 6-bis, di eventuali proposte motivate per l'adozione dei provvedimenti ivi previsti.

3. Nel caso in cui l'attivita' oggetto di SCIA e' condizionata all'acquisizione di atti di assenso comunque denominati o pareri di altri uffici e amministrazioni, ovvero all'esecuzione di verifiche preventive, l'interessato presenta allo sportello di cui al comma 1 la relativa istanza, a seguito della quale e' rilasciata ricevuta ai sensi dell'articolo 18-bis. In tali casi, il termine per la convocazione della conferenza di cui all'articolo 14 decorre dalla data di presentazione dell'istanza e l'inizio dell'attivita' resta subordinato al rilascio degli atti medesimi, di cui lo sportello da' comunicazione all'interessato.

))

### Art. 20. - (Silenzio assenso)

1. Fatta salva l'applicazione dell'articolo 19, nei procedimenti ad istanza di parte per il rilascio di provvedimenti amministrativi il silenzio dell'amministrazione competente equivale a provvedimento di accoglimento della domanda, senza necessita' di ulteriori istanze o diffide, se la medesima amministrazione non comunica all'interessato, nel termine di cui all'articolo 2, commi 2 o 3, il provvedimento di diniego, ovvero non procede ai sensi del comma 2. Tali termini decorrono dalla data di ricevimento della domanda del privato.

2. L'amministrazione competente puo' indire, entro trenta giorni dalla presentazione dell'istanza di cui al comma 1, una conferenza di servizi ai sensi del capo IV, anche tenendo conto delle situazioni giuridiche soggettive dei controinteressati.

2-bis. Nei casi in cui il silenzio dell'amministrazione equivale a provvedimento di accoglimento ai sensi del comma 1, fermi restando gli effetti comunque intervenuti del silenzio assenso, l'amministrazione e' tenuta, su richiesta del privato, a rilasciare, in via telematica, un'attestazione circa il decorso dei termini del procedimento e pertanto dell'intervenuto accoglimento della domanda ai sensi del presente articolo. Decorsi inutilmente dieci giorni dalla richiesta, l'attestazione e' sostituita da una dichiarazione del privato ai sensi ((dell'articolo)) 47 del decreto del Presidente della Repubblica 28 dicembre 2000, n. 445.

3. Nei casi in cui il silenzio dell'amministrazione equivale ad accoglimento della domanda, l'amministrazione competente puo' assumere determinazioni in via di autotutela, ai sensi degli articoli 21-quinquies e 21-nonies.

4. Le disposizioni del presente articolo non si applicano agli atti e procedimenti riguardanti il patrimonio culturale e paesaggistico, l'ambiente, la tutela dal rischio idrogeologico, la difesa nazionale, la pubblica sicurezza, l'immigrazione, l'asilo e la cittadinanza, la salute e la pubblica incolumita', ai casi in cui la normativa comunitaria impone l'adozione di provvedimenti amministrativi formali, ai casi in cui la legge qualifica il silenzio dell'amministrazione come rigetto dell'istanza, nonche' agli atti e procedimenti individuati con uno o piu' decreti del Presidente del Consiglio dei ministri, su proposta del Ministro per la funzione pubblica, di concerto con i Ministri competenti.

5. Si applicano gli articoli 2, comma 7, e 10-bis.

5-bis. COMMA ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104, COME MODIFICATO DAL D.LGS. 15 NOVEMBRE 2011, N. 195.

------------- AGGIORNAMENTO (1a) Il D.P.R. 26 aprile 1992, n. 300 ha disposto: (con l'art. 3, comma 1) che il termine di cui al comma 2, del presente articolo decorre dalla data di ricevimento della denuncia o della domanda del privato. (con l'art. 3, comma 3) che "Qualora la denuncia o la domanda del privato non siano regolari o complete, l'amministrazione ne da' comunicazione al richiedente entro dieci giorni, indicando le cause di irregolarita' o di incompletezza. In questi casi, il termine di cui al comma 1 decorre dal ricevimento della denuncia o della domanda regolari". (con l'art. 3, comma 4) che "Nel caso in cui l'amministrazione non provveda alla comunicazione di cui al comma 3, il termine del procedimento decorre comunque dal ricevimento della denuncia o della domanda".

### Art. 21. - (Disposizioni sanzionatorie)

1. Con la segnalazione o con la domanda di cui agli articoli 19 e 20 l'interessato deve dichiarare la sussistenza dei presupposti e dei requisiti di legge richiesti. In caso di dichiarazioni mendaci o di false attestazioni non e' ammessa la conformazione dell'attivita' e dei suoi effetti a legge o la sanatoria prevista dagli articoli medesimi ed il dichiarante e' punito con la sanzione prevista dell'articolo 483 del codice penale, salvo che il fatto costituisca piu' grave reato.

2. COMMA ABROGATO DALLA L. 7 AGOSTO 2015, N. 124.

2-bis. Restano ferme le attribuzioni di vigilanza, prevenzione e controllo su attivita' soggette ad atti di assenso da parte di pubbliche amministrazioni previste da leggi vigenti, anche se e' stato dato inizio all'attivita' ai sensi degli articoli 19 e 20.

((

2-ter. La decorrenza del termine previsto dall'articolo 19, comma 3, e la formazione del silenzio assenso ai sensi dell'articolo 20 non escludono la responsabilita' del dipendente che non abbia agito tempestivamente nel caso in cui la segnalazione certificata o l'istanza del privato non fosse conforme alle norme vigenti.

))

## EFFICACIA ED INVALIDITA' DEL PROVVEDIMENTO AMMINISTRATIVO. REVOCA E RECESSO))

### Art. 21-bis. - (( (Efficacia del provvedimento limitativo della sfera giuridica dei privati).))

### Art. 21-ter. - (( (Esecutorieta'). ))

((

1. Nei casi e con le modalita' stabiliti dalla legge, le pubbliche amministrazioni possono imporre coattivamente l'adempimento degli obblighi nei loro confronti. Il provvedimento costitutivo di obblighi indica il termine e le modalita' dell'esecuzione da parte del soggetto obbligato. Qualora l'interessato non ottemperi, le pubbliche amministrazioni, previa diffida, possono provvedere all'esecuzione coattiva nelle ipotesi e secondo le modalita' previste dalla legge.

2. Ai fini dell'esecuzione delle obbligazioni aventi ad oggetto somme di denaro si applicano le disposizioni per l'esecuzione coattiva dei crediti dello Stato))

### Art. 21-quater. - (Efficacia ed esecutivita' del provvedimento).

1. I provvedimenti amministrativi efficaci sono eseguiti immediatamente, salvo che sia diversamente stabilito dalla legge o dal provvedimento medesimo.

2. L'efficacia ovvero l'esecuzione del provvedimento amministrativo puo' essere sospesa, per gravi ragioni e per il tempo strettamente necessario, dallo stesso organo che lo ha emanato ovvero da altro organo previsto dalla legge. Il termine della sospensione e' esplicitamente indicato nell'atto che la dispone e puo' essere prorogato o differito per una sola volta, nonche' ridotto per sopravvenute esigenze. ((La sospensione non puo' comunque essere disposta o perdurare oltre i termini per l'esercizio del potere di annullamento di cui all'articolo 21-nonies.))

### Art. 21-quinquies. - (Revoca del provvedimento)

1. ((Per sopravvenuti motivi di pubblico interesse ovvero nel caso di mutamento della situazione di fatto non prevedibile al momento dell'adozione del provvedimento o, salvo che per i provvedimenti di autorizzazione o di attribuzione di vantaggi economici, di nuova valutazione dell'interesse pubblico originario)), il provvedimento amministrativo ad efficacia durevole puo' essere revocato da parte dell'organo che lo ha emanato ovvero da altro organo previsto dalla legge. La revoca determina la inidoneita' del provvedimento revocato a produrre ulteriori effetti. Se la revoca comporta pregiudizi in danno dei soggetti direttamente interessati, l'amministrazione ha l'obbligo di provvedere al loro indennizzo. PERIODO ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104.

1-bis. Ove la revoca di un atto amministrativo ad efficacia durevole o istantanea incida su rapporti negoziali, l'indennizzo liquidato dall'amministrazione agli interessati e' parametrato al solo danno emergente e tiene conto sia dell'eventuale conoscenza o conoscibilita' da parte dei contraenti della contrarieta' dell'atto amministrativo oggetto di revoca all'interesse pubblico, sia dell'eventuale concorso dei contraenti o di altri soggetti all'erronea valutazione della compatibilita' di tale atto con l'interesse pubblico.

1-ter. COMMA ABROGATO DAL D.L. 9 FEBBRAIO 2012, N. 5, CONVERTITO CON MODIFICAZIONI DALLA L. 4 APRILE 2012, N. 35.

### Art. 21-sexies. - (( (Recesso dai contratti).))

### Art. 21-septies. - (Nullita' del provvedimento).

1. E' nullo il provvedimento amministrativo che manca degli elementi essenziali, che e' viziato da difetto assoluto di attribuzione, che e' stato adottato in violazione o elusione del giudicato, nonche' negli altri casi espressamente previsti dalla legge.

2. ((COMMA ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104)).

### Art. 21-octies. - (Annullabilita' del provvedimento).

1. E' annullabile il provvedimento amministrativo adottato in violazione di legge o viziato da eccesso di potere o da incompetenza.

2. Non e' annullabile il provvedimento adottato in violazione di norme sul procedimento o sulla forma degli atti qualora, per la natura vincolata del provvedimento, sia palese che il suo contenuto dispositivo non avrebbe potuto essere diverso da quello in concreto adottato. Il provvedimento amministrativo non e' comunque annullabile per mancata comunicazione dell'avvio del procedimento qualora l'amministrazione dimostri in giudizio che il contenuto del provvedimento non avrebbe potuto essere diverso da quello in concreto adottato. ((La disposizione di cui al secondo periodo non si applica al provvedimento adottato in violazione dell'articolo 10-bis.))

### Art. 21-novies. - (Annullamento d'ufficio).

1. Il provvedimento amministrativo illegittimo ai sensi dell'articolo 21-octies, esclusi i casi di cui al medesimo articolo 21-octies, comma 2, puo' essere annullato d'ufficio, sussistendone le ragioni di interesse pubblico, entro un termine ragionevole, comunque non superiore a dodici mesi dal momento dell'adozione dei provvedimenti di autorizzazione o di attribuzione di vantaggi economici, inclusi i casi in cui il provvedimento si sia formato ai sensi dell'articolo 20, e tenendo conto degli interessi dei destinatari e dei controinteressati, dall'organo che lo ha emanato, ovvero da altro organo previsto dalla legge. Rimangono ferme le responsabilita' connesse all'adozione e al mancato annullamento del provvedimento illegittimo. (39) (41) 2. E' fatta salva la possibilita' di convalida del provvedimento annullabile, sussistendone le ragioni di interesse pubblico ed entro un termine ragionevole. 2-bis. I provvedimenti amministrativi conseguiti sulla base di false rappresentazioni dei fatti o di dichiarazioni sostitutive di certificazione e dell'atto di notorieta' false o mendaci per effetto di condotte costituenti reato, accertate con sentenza passata in giudicato, possono essere annullati dall'amministrazione anche dopo la scadenza del termine di ((dodici)) mesi di cui al comma 1, fatta salva l'applicazione delle sanzioni penali nonche' delle sanzioni previste dal capo VI del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445.

--------------- AGGIORNAMENTO (39) Il D.Lgs. 25 novembre 2016, n. 222 ha disposto (con l'art. 2, comma 4) che "Nei casi del regime amministrativo della Scia, il termine di diciotto mesi di cui all'articolo 21-nonies, comma 1, della legge n. 241 del 1990, decorre dalla data di scadenza del termine previsto dalla legge per l'esercizio del potere ordinario di verifica da parte dell'amministrazione competente. Resta fermo quanto stabilito dall'articolo 21, comma 1, della legge n. 241 del 1990". ------------- AGGIORNAMENTO (41) Il D.L 19 maggio 2020, n. 34, ha disposto (con l'art. 264, comma 1 lettera b) che "Al fine di garantire la massima semplificazione, l'accelerazione dei procedimenti amministrativi e la rimozione di ogni ostacolo burocratico nella vita dei cittadini e delle imprese in relazione all'emergenza COVID-19, dalla data di entrata in vigore del presente decreto e fino al 31 dicembre 2020: [...] b) i provvedimenti amministrativi illegittimi ai sensi dell'art. 21-octies della legge 7 agosto 1990, n. 241, adottati in relazione all'emergenza Covid-19, possono essere annullati d'ufficio, sussistendone le ragioni di interesse pubblico, entro il termine di tre mesi, in deroga all'art. 21-nonies comma 1 della legge 7 agosto 1990, n. 241. Il termine decorre dalla adozione del provvedimento espresso ovvero dalla formazione del silenzio assenso. Resta salva l'annullabilita' d'ufficio anche dopo il termine di tre mesi qualora i provvedimenti amministrativi siano stati adottati sulla base di false rappresentazioni dei fatti o di dichiarazioni sostitutive di certificazione e dell'atto di notorieta' false o mendaci per effetto di condotte costituenti reato, accertate con sentenza passata in giudicato, fatta salva l'applicazione delle sanzioni penali, ivi comprese quelle previste dal capo VI del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445;".

### Art. 21-decies. - (( (Riemissione di provvedimenti annullati dal giudice per vizi inerenti ad atti endoprocedimentali).))

## ACCESSO AI DOCUMENTI AMMINISTRATIVI

### Art. 22. - (Definizioni e principi in materia di accesso).

1. Ai fini del presente capo si intende:

- a) per "diritto di accesso", il diritto degli interessati di prendere visione e di estrarre copia di documenti amministrativi;
- b) per "interessati", tutti i soggetti privati, compresi quelli portatori di interessi pubblici o diffusi, che abbiano un interesse diretto, concreto e attuale, corrispondente ad una situazione giuridicamente tutelata e collegata al documento al quale e' chiesto l'accesso;
- c) per "controinteressati", tutti i soggetti, individuati o facilmente individuabili in base alla natura del documento richiesto, che dall'esercizio dell'accesso vedrebbero compromesso il loro diritto alla riservatezza;
- d) per "documento amministrativo", ogni rappresentazione grafica, fotocinematografica, elettromagnetica o di qualunque altra specie del contenuto di atti, anche interni o non relativi ad uno specifico procedimento, detenuti da una pubblica amministrazione e concernenti attivita' di pubblico interesse, indipendentemente dalla natura pubblicistica o privatistica della loro disciplina sostanziale;
- e) per "pubblica amministrazione", tutti i soggetti di diritto pubblico e i soggetti di diritto privato limitatamente alla loro attivita' di pubblico interesse disciplinata dal diritto nazionale o comunitario.

((2. L'accesso ai documenti amministrativi, attese le sue rilevanti finalita' di pubblico interesse, costituisce principio generale dell'attivita' amministrativa al fine di favorire la partecipazione e di assicurarne l'imparzialita' e la trasparenza))

3. Tutti i documenti amministrativi sono accessibili, ad eccezione di quelli indicati all'articolo 24, commi 1, 2, 3, 5 e 6.

4. Non sono accessibili le informazioni in possesso di una pubblica amministrazione che non abbiano forma di documento amministrativo, salvo quanto previsto dal decreto legislativo 30 giugno 2003, n. 196, in materia di accesso a dati personali da parte della persona cui i dati si riferiscono.

5. L'acquisizione di documenti amministrativi da parte di soggetti pubblici, ove non rientrante nella previsione dell'articolo 43, comma 2, del testo unico delle disposizioni legislative e regolamentari in materia di documentazione amministrativa, di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, si informa al principio di leale cooperazione istituzionale.

6. Il diritto di accesso e' esercitabile fino a quando la pubblica amministrazione ha l'obbligo di detenere i documenti amministrativi ai quali si chiede di accedere.

### Art. 23. - (( (Ambito di applicazione del diritto di accesso) ))

1. Il diritto di accesso di cui all'articolo 22 si esercita nei confronti delle pubbliche amministrazioni, delle aziende autonome e speciali, degli enti pubblici e dei gestori di pubblici servizi. Il diritto di accesso nei confronti delle Autorita' di garanzia e di vigilanza si esercita nell'ambito dei rispettivi ordinamenti, secondo quanto previsto dall'articolo 24.

### Art. 24. - (( (Esclusione dal diritto di accesso).))

((

1. Il diritto di accesso e' escluso:

- a) per i documenti coperti da segreto di Stato ai sensi della legge 24 ottobre 1977, n. 801, e successive modificazioni, e nei casi di segreto o di divieto di divulgazione espressamente previsti dalla legge, dal regolamento governativo di cui al comma 6 e dalle pubbliche amministrazioni ai sensi del comma 2 del presente articolo;
- b) nei procedimenti tributari, per i quali restano ferme le particolari norme che li regolano;
- c) nei confronti dell'attivita' della pubblica amministrazione diretta all'emanazione di atti normativi, amministrativi generali, di pianificazione e di programmazione, per i quali restano ferme le particolari norme che ne regolano la formazione;
- d) nei procedimenti selettivi, nei confronti dei documenti amministrativi contenenti informazioni di carattere psicoattitudinale relativi a terzi.

2. Le singole pubbliche amministrazioni individuano le categorie di documenti da esse formati o comunque rientranti nella loro disponibilita' sottratti all'accesso ai sensi del comma 1.

3. Non sono ammissibili istanze di accesso preordinate ad un controllo generalizzato dell'operato delle pubbliche amministrazioni.

4. L'accesso ai documenti amministrativi non puo' essere negato ove sia sufficiente fare ricorso al potere di differimento.

5. I documenti contenenti informazioni connesse agli interessi di cui al comma 1 sono considerati segreti solo nell'ambito e nei limiti di tale connessione. A tale fine le pubbliche amministrazioni fissano, per ogni categoria di documenti, anche l'eventuale periodo di tempo per il quale essi sono sottratti all'accesso.

6. Con regolamento, adottato ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, il Governo puo' prevedere casi di sottrazione all'accesso di documenti amministrativi:

- a) quando, al di fuori delle ipotesi disciplinate dall'articolo 12 della legge 24 ottobre 1977, n. 801, dalla loro divulgazione possa derivare una lesione, specifica e individuata, alla sicurezza e alla difesa nazionale, all'esercizio della sovranita' nazionale e alla continuita' e alla correttezza delle relazioni internazionali, con particolare riferimento alle ipotesi previste dai trattati e dalle relative leggi di attuazione;
- b) quando l'accesso possa arrecare pregiudizio ai processi di formazione, di determinazione e di attuazione della politica monetaria e valutaria;
- c) quando i documenti riguardino le strutture, i mezzi, le dotazioni, il personale e le azioni strettamente strumentali alla tutela dell'ordine pubblico, alla prevenzione e alla repressione della criminalita' con particolare riferimento alle tecniche investigative, alla identita' delle fonti di informazione e alla sicurezza dei beni e delle persone coinvolte, all'attivita' di polizia giudiziaria e di conduzione delle indagini;
- d) quando i documenti riguardino la vita privata o la riservatezza di persone fisiche, persone giuridiche, gruppi, imprese e associazioni, con particolare riferimento agli interessi epistolare, sanitario, professionale, finanziario, industriale e commerciale di cui siano in concreto titolari, ancorche' i relativi dati siano forniti all'amministrazione dagli stessi soggetti cui si riferiscono;
- e) quando i documenti riguardino l'attivita' in corso di contrattazione collettiva nazionale di lavoro e gli atti interni connessi all'espletamento del relativo mandato.

7. Deve comunque essere garantito ai richiedenti l'accesso ai documenti amministrativi la cui conoscenza sia necessaria per curare o per difendere i propri interessi giuridici. Nel caso di documenti contenenti dati sensibili e giudiziari, l'accesso e' consentito nei limiti in cui sia strettamente indispensabile e nei termini previsti dall'articolo 60 del decreto legislativo 30 giugno 2003, n. 196, in caso di dati idonei a rivelare lo stato di salute e la vita sessuale))

### Art. 25. - (Modalita' di esercizio del diritto di accesso e ricorsi)

1. Il diritto di accesso si esercita mediante esame ed estrazione di copia dei documenti amministrativi, nei modi e con i limiti indicati dalla presente legge. L'esame dei documenti e' gratuito. Il rilascio di copia e' subordinato soltanto al rimborso del costo di riproduzione, salve le disposizioni vigenti in materia di bollo, nonche' i diritti di ricerca e di visura.

2. La richiesta di accesso ai documenti deve essere motivata. Essa deve essere rivolta all'amministrazione che ha formato il documento o che lo detiene stabilmente.

3. Il rifiuto, il differimento e la limitazione dell'accesso sono ammessi nei casi e nei limiti stabiliti dall'articolo 24 e debbono essere motivati.

4. Decorsi inutilmente trenta giorni dalla richiesta, questa si intende respinta. In caso di diniego dell'accesso, espresso o tacito, o di differimento dello stesso ai sensi dell'articolo 24, comma 4, il richiedente puo' presentare ricorso al tribunale amministrativo regionale ai sensi del comma 5, ovvero chiedere, nello stesso termine e nei confronti degli atti delle amministrazioni comunali, provinciali e regionali, al difensore civico competente per ambito territoriale, ove costituito, che sia riesaminata la suddetta determinazione. Qualora tale organo non sia stato istituito, la competenza e' attribuita al difensore civico competente per l'ambito territoriale immediatamente superiore. Nei confronti degli atti delle amministrazioni centrali e periferiche dello Stato tale richiesta e' inoltrata presso la Commissione per l'accesso di cui all'articolo 27 nonche' presso l'amministrazione resistente. Il difensore civico o la Commissione per l'accesso si pronunciano entro trenta giorni dalla presentazione dell'istanza. Scaduto infruttuosamente tale termine, il ricorso si intende respinto. Se il difensore civico o la Commissione per l'accesso ritengono illegittimo il diniego o il differimento, ne informano il richiedente e lo comunicano all'autorita' disponente. Se questa non emana il provvedimento confermativo motivato entro trenta giorni dal ricevimento della comunicazione del difensore civico o della Commissione, l'accesso e' consentito. Qualora il richiedente l'accesso si sia rivolto al difensore civico o alla Commissione, il termine di cui al comma 5 decorre dalla data di ricevimento, da parte del richiedente, dell'esito della sua istanza al difensore civico o alla Commissione stessa. Se l'accesso e' negato o differito per motivi inerenti ai dati personali che si riferiscono a soggetti terzi, la Commissione provvede, sentito il Garante per la protezione dei dati personali, il quale si pronuncia entro il termine di dieci giorni dalla richiesta, decorso inutilmente il quale il parere si intende reso. Qualora un procedimento di cui alla sezione III del capo I del titolo I della parte III del decreto legislativo 30 giugno 2003, n. 196, o di cui agli articoli 154, 157, 158, 159 e 160 del medesimo decreto legislativo n. 196 del 2003, relativo al trattamento pubblico di dati personali da parte di una pubblica amministrazione, interessi l'accesso ai documenti amministrativi, il Garante per la protezione dei dati personali chiede il parere, obbligatorio e non vincolante, della Commissione per l'accesso ai documenti amministrativi. La richiesta di parere sospende il termine per la pronuncia del Garante sino all'acquisizione del parere, e comunque per non oltre quindici giorni. Decorso inutilmente detto termine, il Garante adotta la propria decisione.

((

5. Le controversie relative all'accesso ai documenti amministrativi sono disciplinate dal codice del processo amministrativo.

))

5-bis. ((COMMA ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104)).

6. ((COMMA ABROGATO DAL D.LGS. 2 LUGLIO 2010, N. 104)).

### Art. 26. - (Obbligo di pubblicazione)

1.((COMMA ABROGATO DAL D.LGS. 14 MARZO 2013, N. 33)).

2. Sono altresi' pubblicate, nelle forme predette, le relazioni annuali della Commissione di cui all'articolo 27 e, in generale, e' data la massima pubblicita' a tutte le disposizioni attuative della presente legge e a tutte le iniziative dirette a precisare ed a rendere effettivo il diritto di accesso.

3. Con la pubblicazione di cui al comma 1, ove essa sia integrale, la liberta' di accesso ai documenti indicati nel predetto comma 1 s'intende realizzata.

### Art. 27. - (Commissione per l'accesso ai documenti amministrativi).

1. E' istituita presso la Presidenza del Consiglio dei Ministri la Commissione per l'accesso ai documenti amministrativi.

2. La Commissione e' nominata con decreto del Presidente del Consiglio dei Ministri, sentito il Consiglio dei Ministri. Essa e' presieduta dal sottosegretario di Stato alla Presidenza del Consiglio dei Ministri ed ((e' composta da dieci membri)), dei quali due senatori e due deputati, designati dai Presidenti delle rispettive Camere, quattro scelti fra il personale di cui alla legge 2 aprile 1979, n. 97, ((anche in quiescenza,)) su designazione dei rispettivi organi di autogoverno, ((e uno scelto fra i professori di ruolo)) in materie giuridiche ((...)). E' membro di diritto della Commissione il capo della struttura della Presidenza del Consiglio dei Ministri che costituisce il supporto organizzativo per il funzionamento della Commissione. La Commissione puo' avvalersi di un numero di esperti non superiore a cinque unita', nominati ai sensi dell'articolo 29 della legge 23 agosto 1988, n. 400.

((2-bis. La Commissione delibera a maggioranza dei presenti. L'assenza dei componenti per tre sedute consecutive ne determina la decadenza))

3. La Commissione e' rinnovata ogni tre anni. Per i membri parlamentari si procede a nuova nomina in caso di scadenza o scioglimento anticipato delle Camere nel corso del triennio.

4. COMMA ABROGATO DAL D.P.R. 2 AGOSTO 2007, N. 157.

5. La Commissione adotta le determinazioni previste dall'articolo 25, comma 4; vigila affinche' sia attuato il principio di piena conoscibilita' dell'attivita' della pubblica amministrazione con il rispetto dei limiti fissati dalla presente legge; redige una relazione annuale sulla trasparenza dell'attivita' della pubblica amministrazione, che comunica alle Camere e al Presidente del Consiglio dei Ministri; propone al Governo modifiche dei testi legislativi e regolamentari che siano utili a realizzare la piu' ampia garanzia del diritto di accesso di cui all'articolo 22.

6. Tutte le amministrazioni sono tenute a comunicare alla Commissione, nel termine assegnato dalla medesima, le informazioni ed i documenti da essa richiesti, ad eccezione di quelli coperti da segreto di Stato.

7. COMMA ABROGATO DAL D.P.R. 2 AGOSTO 2007, N. 157. ((30)) ------------- AGGIORNAMENTI (30) Il D.L. 21 giugno 2013, n. 69, convertito con modificazioni dalla L. 9 agosto 2013, n. 98, ha disposto (con l'art. 47-bis, comma 2) che "La Commissione di cui all'articolo 27 della legge 7 agosto 1990, n. 241, come da ultimo modificato dal presente articolo, e' ricostituita entro sessanta giorni dalla data di entrata in vigore della legge di conversione del presente decreto. Fino alla data di nuova costituzione, la Commissione continua a operare nella precedente composizione".

### Art. 28. - (( (Modifica dell'articolo 15 del testo unico di cui al decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, in materia di segreto di ufficio) ))

1. L'articolo 15 del testo unico delle disposizioni concernenti lo statuto degli impiegati civili dello Stato, approvato con decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, e' sostituito dal seguente; "Art. 15. - (Segreto d'ufficio). - 1. L'impiegato deve mantenere il segreto d'ufficio. Non puo' trasmettere a chi non ne abbia diritto informazioni riguardanti provvedimenti od operazioni amministrative, in corso o concluse, ovvero notizie di cui sia venuto a conoscenza a causa delle sue funzioni, al di fuori delle ipotesi e delle modalita' previste dalle norme sul diritto di accesso. Nell'ambito delle proprie attribuzioni, l'impiegato preposto ad un ufficio rilascia copie ed estratti di atti e documenti di ufficio nei casi non vietati dall'ordinamento".

## DISPOSIZIONI FINALI

### Art. 29. - (Ambito di applicazione della legge).

1. Le disposizioni della presente legge si applicano alle amministrazioni statali e agli enti pubblici nazionali. Le disposizioni della presente legge si applicano, altresi', alle societa' con totale o prevalente capitale pubblico, limitatamente all'esercizio delle funzioni amministrative. Le disposizioni di cui agli articoli 2-bis, 11, 15 e 25, commi 5, 5-bis e 6, nonche' quelle del capo IV-bis si applicano a tutte le amministrazioni pubbliche.

2. Le regioni e gli enti locali, nell'ambito delle rispettive competenze, regolano le materie disciplinate dalla presente legge nel rispetto del sistema costituzionale e delle garanzie del cittadino nei riguardi dell'azione amministrativa, cosi' come definite dai principi stabiliti dalla presente legge.

2-bis. Attengono ai livelli essenziali delle prestazioni di cui all'articolo 117, secondo comma, lettera m), della Costituzione le disposizioni della presente legge concernenti gli obblighi per la pubblica amministrazione di garantire la partecipazione dell'interessato al procedimento, di individuarne un responsabile, di concluderlo entro il termine prefissato ((, di misurare i tempi effettivi di conclusione dei procedimenti)) e di assicurare l'accesso alla documentazione amministrativa, nonche' quelle relative alla durata massima dei procedimenti.

2-ter. Attengono altresi' ai livelli essenziali delle prestazioni di cui all'articolo 117, secondo comma, lettera m), della Costituzione le disposizioni della presente legge concernenti la presentazione di istanze, segnalazioni e comunicazioni, la segnalazione certificata di inizio attivita' e il silenzio assenso e la conferenza di servizi, salva la possibilita' di individuare, con intese in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e successive modificazioni, casi ulteriori in cui tali disposizioni non si applicano.

2-quater. Le regioni e gli enti locali, nel disciplinare i procedimenti amministrativi di loro competenza, non possono stabilire garanzie inferiori a quelle assicurate ai privati dalle disposizioni attinenti ai livelli essenziali delle prestazioni di cui ai commi 2-bis e 2-ter, ma possono prevedere livelli ulteriori di tutela.

2-quinquies. Le regioni a statuto speciale e le province autonome di Trento e di Bolzano adeguano la propria legislazione alle disposizioni del presente articolo, secondo i rispettivi statuti e le relative norme di attuazione.

### Art. 30. - (( (Atti di notorieta') ))

1. In tutti i casi in cui le leggi e i regolamenti prevedono atti di notorieta' o attestazioni asseverate da testimoni altrimenti denominate, il numero dei testimoni e' ridotto a due.

2. E' fatto divieto alle pubbliche amministrazioni e alle imprese esercenti servizi di pubblica necessita' e di pubblica utilita' di esigere atti di notorieta' in luogo della dichiarazione sostitutiva dell'atto di notorieta' prevista dall'articolo 4 della legge 4 gennaio 1968, n. 15, quando si tratti di provare qualita' personali, stati o fatti che siano a diretta conoscenza dell'interessato.

### Art. 31.

((ARTICOLO ABROGATO DALLA L. 11 FEBBRAIO 2005, N. 15))

